.. note::

  This library is free to use under the
  `MIT license <https://github.com/tdegeus/GooseBib/blob/master/LICENSE>`_.
  Any additions are very much appreciated, in terms of suggested functionality,
  code, documentation, testimonials, word of mouth advertisement, etc.
  Bug reports or feature requests can be filed on `GitHub <http://github.com/tdegeus/GooseBib>`_.
  As always, the code comes with no guarantee.
  None of the developers can be held responsible for possible mistakes.

  Download:
  `.zip file <https://github.com/tdegeus/GooseBib/zipball/master>`_ |
  `.tar.gz file <https://github.com/tdegeus/GooseBib/tarball/master>`_.

  (c - `MIT <https://github.com/tdegeus/GooseBib/blob/master/LICENSE>`_) T.W.J. de Geus (Tom) |
  tom@geus.me |
  `www.geus.me <http://www.geus.me>`_ |
  `github.com/tdegeus/GooseBib <http://github.com/tdegeus/GooseBib>`_

Contents
========

.. toctree::
   :maxdepth: 1

   install.rst
   usage.rst
   tools.rst
   module.rst
   zotero.rst
